@@ -86,7 +86,7 @@ do_connect_dialog_for_dsn (const gchar *dsn)
 						  gnome_db_login_get_dsn (GNOME_DB_LOGIN (login)),
 						  gnome_db_login_get_username (GNOME_DB_LOGIN (login)),
 						  gnome_db_login_get_password (GNOME_DB_LOGIN (login)),
-						  0);
+						  0, NULL);
 	}
 
 	gtk_widget_destroy (dialog);
@@ -182,6 +182,8 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 
 			if (gnome_db_login_dialog_run (GNOME_DB_LOGIN_DIALOG (dialog))) {
 				GtkWidget *msgdialog;
+				GError *error = NULL;
+
 				if (!db_client) 
 					db_client = gda_client_new ();
 				
@@ -189,7 +191,7 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 								  gnome_db_login_get_dsn (GNOME_DB_LOGIN (login)),
 								  gnome_db_login_get_username (GNOME_DB_LOGIN (login)),
 								  gnome_db_login_get_password (GNOME_DB_LOGIN (login)),
-								  0);
+								  0, &error);
 				if (cnc && GDA_IS_CONNECTION (cnc)) {
 					str = g_strdup_printf ("<b>%s</b>", _("Connection successfully opened!"));
 					msgdialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (dialog), GTK_DIALOG_MODAL,
@@ -198,7 +200,13 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 					gda_connection_close (cnc);
 				}
 				else {
-					str = g_strdup_printf ("<b>%s</b>", _("Could not open connection."));
+					if (error) {
+						str = g_strdup_printf ("<b>%s:</b>\n%s", _("Could not open connection"), 
+								       error->message ? error->message : _("Unknown error"));
+						g_error_free (error);
+					}
+					else
+						str = g_strdup_printf ("<b>%s</b>", _("Could not open connection"));
 					msgdialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (dialog), GTK_DIALOG_MODAL,
 											GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, str);
 					g_free (str);
