@@ -67,7 +67,6 @@ static gboolean    gnome_db_condition_load_from_xml (GnomeDbXmlStorage *iface, x
 
 /* Renderer interface */
 static void            gnome_db_condition_renderer_init      (GnomeDbRendererIface *iface);
-static GdaXqlItem     *gnome_db_condition_render_as_xql   (GnomeDbRenderer *iface, GnomeDbDataSet *context, GError **error);
 static gchar          *gnome_db_condition_render_as_sql   (GnomeDbRenderer *iface, GnomeDbDataSet *context, guint options, GError **error);
 static gchar          *gnome_db_condition_render_as_str   (GnomeDbRenderer *iface, GnomeDbDataSet *context);
 
@@ -164,10 +163,10 @@ gnome_db_condition_get_type (void)
                         NULL
                 };
 
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbCondition", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-                g_type_add_interface_static (type, GNOME_DB_RENDERER_TYPE, &renderer_info);
-                g_type_add_interface_static (type, GNOME_DB_REFERER_TYPE, &referer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbCondition", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+                g_type_add_interface_static (type, GNOME_DB_TYPE_RENDERER, &renderer_info);
+                g_type_add_interface_static (type, GNOME_DB_TYPE_REFERER, &referer_info);
 	}
 	return type;
 }
@@ -183,7 +182,6 @@ gnome_db_condition_xml_storage_init (GnomeDbXmlStorageIface *iface)
 static void
 gnome_db_condition_renderer_init (GnomeDbRendererIface *iface)
 {
-        iface->render_as_xql = gnome_db_condition_render_as_xql;
         iface->render_as_sql = gnome_db_condition_render_as_sql;
         iface->render_as_str = gnome_db_condition_render_as_str;
 	iface->is_valid = NULL;
@@ -262,7 +260,7 @@ gnome_db_condition_new (GnomeDbQuery *query, GnomeDbConditionType type)
 	g_return_val_if_fail (query && IS_GNOME_DB_QUERY (query), NULL);
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
 
-	obj = g_object_new (GNOME_DB_CONDITION_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_CONDITION, "dict", dict, NULL);
 	g_object_get (G_OBJECT (query), "cond_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (obj), id);
 
@@ -318,7 +316,7 @@ gnome_db_condition_new_copy (GnomeDbCondition *orig, GHashTable *replacements)
 	g_return_val_if_fail (query, NULL);
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
 
-	obj = g_object_new (GNOME_DB_CONDITION_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_CONDITION, "dict", dict, NULL);
 	g_object_get (G_OBJECT (query), "cond_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (obj), id);
 
@@ -866,7 +864,7 @@ gnome_db_condition_leaf_set_operator (GnomeDbCondition *condition, GnomeDbCondit
 	g_return_if_fail (query1);
 	g_return_if_fail (query1 == query2);
 
-	gnome_db_ref_base_set_ref_object_type (condition->priv->ops[op], GNOME_DB_BASE (field), GNOME_DB_QFIELD_TYPE);
+	gnome_db_ref_base_set_ref_object_type (condition->priv->ops[op], GNOME_DB_BASE (field), GNOME_DB_TYPE_QFIELD);
 }
 
 /**
@@ -1468,7 +1466,7 @@ gnome_db_condition_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GEr
 
 	prop = xmlGetProp (node, "l_op");
 	if (prop) {
-		gnome_db_ref_base_set_ref_name (cond->priv->ops[GNOME_DB_CONDITION_OP_LEFT], GNOME_DB_QFIELD_TYPE,
+		gnome_db_ref_base_set_ref_name (cond->priv->ops[GNOME_DB_CONDITION_OP_LEFT], GNOME_DB_TYPE_QFIELD,
 					  REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
@@ -1476,14 +1474,14 @@ gnome_db_condition_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GEr
 
 	prop = xmlGetProp (node, "r_op");
 	if (prop) {
-		gnome_db_ref_base_set_ref_name (cond->priv->ops[GNOME_DB_CONDITION_OP_RIGHT], GNOME_DB_QFIELD_TYPE,
+		gnome_db_ref_base_set_ref_name (cond->priv->ops[GNOME_DB_CONDITION_OP_RIGHT], GNOME_DB_TYPE_QFIELD,
 					  REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
 
 	prop = xmlGetProp (node, "r_op2");
 	if (prop) {
-		gnome_db_ref_base_set_ref_name (cond->priv->ops[GNOME_DB_CONDITION_OP_RIGHT2], GNOME_DB_QFIELD_TYPE,
+		gnome_db_ref_base_set_ref_name (cond->priv->ops[GNOME_DB_CONDITION_OP_RIGHT2], GNOME_DB_TYPE_QFIELD,
 					  REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
@@ -1521,17 +1519,6 @@ gnome_db_condition_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GEr
 /*
  * GnomeDbRenderer interface implementation
  */
-static GdaXqlItem *
-gnome_db_condition_render_as_xql (GnomeDbRenderer *iface, GnomeDbDataSet *context, GError **error)
-{
-        GdaXqlItem *node = NULL;
-
-        g_return_val_if_fail (iface && IS_GNOME_DB_CONDITION (iface), NULL);
-        g_return_val_if_fail (GNOME_DB_CONDITION (iface)->priv, NULL);
-
-        TO_IMPLEMENT;
-        return node;
-}
 
 static gchar *
 gnome_db_condition_render_as_sql (GnomeDbRenderer *iface, GnomeDbDataSet *context, guint options, GError **error)
