@@ -277,7 +277,7 @@ GQuark gnome_db_data_proxy_error_quark (void)
         return quark;
 }
 
-guint
+GType
 gnome_db_data_proxy_get_type (void)
 {
 	static GType type = 0;
@@ -301,7 +301,7 @@ gnome_db_data_proxy_get_type (void)
 			NULL
 		};
 
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbDataProxy", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbDataProxy", &info, 0);
 		g_type_add_interface_static (type, GTK_TYPE_TREE_MODEL, &tree_model_info);
 	}
 	return type;
@@ -392,7 +392,7 @@ gnome_db_data_proxy_new (GnomeDbDataModel *model)
 
 	g_return_val_if_fail (model && IS_GNOME_DB_DATA_MODEL (model), NULL);
 
-	obj = g_object_new (GNOME_DB_DATA_PROXY_TYPE, "dict", gnome_db_base_get_dict (GNOME_DB_BASE (model)), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_DATA_PROXY, "dict", gnome_db_base_get_dict (GNOME_DB_BASE (model)), NULL);
 	proxy = GNOME_DB_DATA_PROXY (obj);
 
 	g_object_ref (model);
@@ -1500,7 +1500,7 @@ commit_row_modif (GnomeDbDataProxy *proxy, RowModif *rm, GError **error)
 					gda_row_set_is_default (gdarow, i, TRUE);
 			}
 			err = ! gda_data_model_update_row (GDA_DATA_MODEL (proxy->priv->model), gdarow);
-			gda_row_free (gdarow);
+			g_object_unref (gdarow);
 			g_free (is_default);
 		}
 		else {
@@ -1537,7 +1537,7 @@ commit_row_modif (GnomeDbDataProxy *proxy, RowModif *rm, GError **error)
 				}
 			}
 			err = ! gda_data_model_append_row (GDA_DATA_MODEL (proxy->priv->model), gdarow);
-			gda_row_free (gdarow);
+			g_object_unref (gdarow);
 			g_free (is_default);
 		}
 	}
@@ -1795,6 +1795,18 @@ data_proxy_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, gint column,
 						}
 					}
 				}
+
+				if (what == 1) {
+					/* compute the GNOME_DB_VALUE_DATA_NON_VALID attribute */
+					if (! (proxy->priv->cols_non_modif_attrs[model_col] & GNOME_DB_VALUE_CAN_BE_NULL)) {
+						guint retval;
+						retval = g_value_get_uint (value);
+						if (retval & GNOME_DB_VALUE_IS_NULL) {
+							retval |= GNOME_DB_VALUE_DATA_NON_VALID;
+							g_value_set_uint (value, retval);
+						}
+					}
+				}
 			}
 		}
 	}
