@@ -60,7 +60,6 @@ static GnomeDbServerDataType *gnome_db_qf_field_get_data_type   (GnomeDbField *i
 
 /* Renderer interface */
 static void            gnome_db_qf_field_renderer_init   (GnomeDbRendererIface *iface);
-static GdaXqlItem     *gnome_db_qf_field_render_as_xql   (GnomeDbRenderer *iface, GnomeDbDataSet *context, GError **error);
 static gchar          *gnome_db_qf_field_render_as_sql   (GnomeDbRenderer *iface, GnomeDbDataSet *context, guint options, GError **error);
 static gchar          *gnome_db_qf_field_render_as_str   (GnomeDbRenderer *iface, GnomeDbDataSet *context);
 
@@ -173,11 +172,11 @@ gnome_db_qf_field_get_type (void)
 		};
 		
 		
-		type = g_type_register_static (GNOME_DB_QFIELD_TYPE, "GnomeDbQfField", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-		g_type_add_interface_static (type, GNOME_DB_FIELD_TYPE, &field_info);
-		g_type_add_interface_static (type, GNOME_DB_RENDERER_TYPE, &renderer_info);
-		g_type_add_interface_static (type, GNOME_DB_REFERER_TYPE, &referer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_QFIELD, "GnomeDbQfField", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_FIELD, &field_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_RENDERER, &renderer_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_REFERER, &referer_info);
 	}
 	return type;
 }
@@ -200,7 +199,6 @@ gnome_db_qf_field_field_init (GnomeDbFieldIface *iface)
 static void
 gnome_db_qf_field_renderer_init (GnomeDbRendererIface *iface)
 {
-	iface->render_as_xql = gnome_db_qf_field_render_as_xql;
 	iface->render_as_sql = gnome_db_qf_field_render_as_sql;
 	iface->render_as_str = gnome_db_qf_field_render_as_str;
 	iface->is_valid = NULL;
@@ -309,7 +307,7 @@ gnome_db_qf_field_new_with_objects (GnomeDbQuery *query, GnomeDbTarget *target,
 
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
 
-	obj = g_object_new (GNOME_DB_QF_FIELD_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_QF_FIELD, "dict", dict, NULL);
 	gnome_db_qf_field = GNOME_DB_QF_FIELD (obj);
 	g_object_get (G_OBJECT (query), "field_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_qf_field), id);
@@ -330,7 +328,7 @@ gnome_db_qf_field_new_with_objects (GnomeDbQuery *query, GnomeDbTarget *target,
 }
 
 /**
- * gnome_db_qf_field_new_with_xml_id
+ * gnome_db_qf_field_new_with_xml_ids
  * @query: a #GnomeDbQuery in which the new object will be
  * @target_xml_id: the XML Id of a #GnomeDbTarget object
  * @field_xml_id: the XML Id of an object which implements the #GnomeDbField interface
@@ -364,7 +362,7 @@ gnome_db_qf_field_new_with_xml_ids (GnomeDbQuery *query, const gchar *target_xml
 	g_free (str);
 
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
-	obj = g_object_new (GNOME_DB_QF_FIELD_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_QF_FIELD, "dict", dict, NULL);
 	gnome_db_qf_field = GNOME_DB_QF_FIELD (obj);
 	g_object_get (G_OBJECT (query), "field_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_qf_field), id);
@@ -376,10 +374,10 @@ gnome_db_qf_field_new_with_xml_ids (GnomeDbQuery *query, const gchar *target_xml
 			  G_CALLBACK (target_removed_cb), gnome_db_qf_field);
 
 	gnome_db_qf_field->priv->target_ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (dict));
-	gnome_db_ref_base_set_ref_name (gnome_db_qf_field->priv->target_ref, GNOME_DB_TARGET_TYPE, REFERENCE_BY_XML_ID, target_xml_id);
+	gnome_db_ref_base_set_ref_name (gnome_db_qf_field->priv->target_ref, GNOME_DB_TYPE_TARGET, REFERENCE_BY_XML_ID, target_xml_id);
 
 	gnome_db_qf_field->priv->field_ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (dict));
-	gnome_db_ref_base_set_ref_name (gnome_db_qf_field->priv->field_ref, GNOME_DB_FIELD_TYPE, REFERENCE_BY_XML_ID, field_xml_id);
+	gnome_db_ref_base_set_ref_name (gnome_db_qf_field->priv->field_ref, GNOME_DB_TYPE_FIELD, REFERENCE_BY_XML_ID, field_xml_id);
 	
 	return obj;
 }
@@ -502,7 +500,7 @@ gnome_db_qf_field_set_property (GObject              *object,
 				if (!gnome_db_qf_field->priv->value_prov_ref)
 					gnome_db_qf_field->priv->value_prov_ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (gnome_db_base_get_dict (GNOME_DB_BASE (gnome_db_qf_field))));
 				gnome_db_ref_base_set_ref_object_type (gnome_db_qf_field->priv->value_prov_ref,
-								 ptr, GNOME_DB_FIELD_TYPE);
+								 ptr, GNOME_DB_TYPE_FIELD);
 			}
 			else {
 				if (gnome_db_qf_field->priv->value_prov_ref) {
@@ -526,7 +524,7 @@ gnome_db_qf_field_set_property (GObject              *object,
 				if (!gnome_db_qf_field->priv->value_prov_ref)
 					gnome_db_qf_field->priv->value_prov_ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (gnome_db_base_get_dict (GNOME_DB_BASE (gnome_db_qf_field))));
 				gnome_db_ref_base_set_ref_name (gnome_db_qf_field->priv->value_prov_ref,
-							  GNOME_DB_FIELD_TYPE, REFERENCE_BY_XML_ID, val);
+							  GNOME_DB_TYPE_FIELD, REFERENCE_BY_XML_ID, val);
 			}
 			else {
 				if (gnome_db_qf_field->priv->value_prov_ref) {
@@ -878,14 +876,14 @@ gnome_db_qf_field_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GErr
 	prop = xmlGetProp (node, "target");
 	if (prop) {
 		target = TRUE;
-		gnome_db_ref_base_set_ref_name (field->priv->target_ref, GNOME_DB_TARGET_TYPE, REFERENCE_BY_XML_ID, prop);
+		gnome_db_ref_base_set_ref_name (field->priv->target_ref, GNOME_DB_TYPE_TARGET, REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
 
 	prop = xmlGetProp (node, "object");
 	if (prop) {
 		target = TRUE;
-		gnome_db_ref_base_set_ref_name (field->priv->field_ref, GNOME_DB_FIELD_TYPE, REFERENCE_BY_XML_ID, prop);
+		gnome_db_ref_base_set_ref_name (field->priv->field_ref, GNOME_DB_TYPE_FIELD, REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
 
@@ -932,17 +930,6 @@ gnome_db_qf_field_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GErr
 /*
  * GnomeDbRenderer interface implementation
  */
-static GdaXqlItem *
-gnome_db_qf_field_render_as_xql (GnomeDbRenderer *iface, GnomeDbDataSet *context, GError **error)
-{
-	GdaXqlItem *node = NULL;
-
-	g_return_val_if_fail (iface && IS_GNOME_DB_QF_FIELD (iface), NULL);
-	g_return_val_if_fail (GNOME_DB_QF_FIELD (iface)->priv, NULL);
-	
-	TO_IMPLEMENT;
-	return node;
-}
 
 static gchar *
 gnome_db_qf_field_render_as_sql (GnomeDbRenderer *iface, GnomeDbDataSet *context, guint options, GError **error)
