@@ -59,7 +59,7 @@ static gint gnome_db_selector_signals[LAST_SIGNAL] = { 0 };
 static GObjectClass *parent_class = NULL;
 
 
-guint
+GType
 gnome_db_selector_get_type (void)
 {
 	static GType type = 0;
@@ -151,7 +151,7 @@ gnome_db_selector_new (GnomeDbDict *dict, GObject *ref_object, gulong mode, gulo
 
 	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 		
-	obj = g_object_new (GNOME_DB_SELECTOR_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_SELECTOR, NULL);
 	mgsel = GNOME_DB_SELECTOR (obj);
 
 	mgsel->priv->dict = ASSERT_DICT (dict);
@@ -808,6 +808,38 @@ gnome_db_selector_set_column_label (GnomeDbSelector *mgsel, guint column, const
 	gtk_tree_view_column_set_title (tcolumn, label);
 }
 
+/**
+ * gnome_db_selector_expand_all
+ * @mgsel:
+ *
+ * Recursively expands all nodes in the @mgsel widget.
+ */
+void
+gnome_db_selector_expand_all (GnomeDbSelector *mgsel)
+{
+	g_return_if_fail (mgsel && IS_GNOME_DB_SELECTOR (mgsel));
+	g_return_if_fail (mgsel->priv);
+
+	if (mgsel->priv->treeview)
+		gtk_tree_view_expand_all (mgsel->priv->treeview);
+}
+
+/**
+ * gnome_db_selector_collapse_all
+ * @mgsel:
+ *
+ * Recursively collapse all nodes in the @mgsel widget.
+ */
+void
+gnome_db_selector_collapse_all (GnomeDbSelector *mgsel)
+{
+	g_return_if_fail (mgsel && IS_GNOME_DB_SELECTOR (mgsel));
+	g_return_if_fail (mgsel->priv);
+
+	if (mgsel->priv->treeview)
+		gtk_tree_view_collapse_all (mgsel->priv->treeview);
+}
+
 
 /**
  * gnome_db_selector_get_selected_object
